==> PPDF_1_1.zip: PubMedPDF/edit_wopmid.php <==
<?php
	include "header.php";
	include "include/db.php";
	include "include/Get_Journal.php";
	include "style.php";

	## edit

	$id = @$_GET["id"];

	$sql = "SELECT * FROM ".$T_ID." WHERE id=$id";
	$res = mysql_query($sql, $conn);

	if(!$row = mysql_fetch_array($res, MYSQL_ASSOC)) break;
	$item = array(
		"a"=>$row["Author"], "t"=>$row["Title"], "v"=>$row["Volume"], "p"=>$row["Page"], 
		"y"=>$row["Year"], "ab"=>$row["Abstract"], "j"=>$row["Journal"], "e"=>$row["editor"],
		"pub"=>$row["Publisher"], "t_jp"=>$row["Title_JP"], "a_jp"=>$row["Author_JP"],
		"c_t1"=>$row["Custom_t1"]
		);

// Edit form
	echo "<div class=\"pt\">"._MD_EDIT_INFO."</div>";
	echo "<br><form enctype=\"multipart/form-data\" action=\"modify_wopmid.php\" method=\"POST\">";
	echo "<div class=\"pc\">";
	echo "<table>";

// Title
	$item[t] = str_replace( '"', '&#34;', $item[t] );
	$item[t_jp] = str_replace( '"', '&#34;', $item[t_jp] );

	echo "<tr><td colspan=\"2\" style=\"text-align:left\;\"><b>Title</b></td></tr>";
	echo "<tr><td style=\"width:140px\" >&nbsp;&nbsp;*in English</td>";
	echo "<td><input type=\"text\" style=\"width:90%\" name=\"title_e\" value=\"".$item[t]."\"></td></tr>";

	echo "<tr><td>&nbsp;&nbsp; in other Language</td>";
	echo "<td><input type=\"text\" style=\"width:90%\" name=\"title_o\" value=\"".$item[t_jp]."\"></td></tr>";

// Authors
	$a = $item[a];
	$author="";
	$a = explode(",",substr($a,0,-1));
	for($k=0; $k<count($a); $k++){
		$a[$k] = str_replace("[","",$a[$k]);
		$a[$k] = str_replace("]","",$a[$k]);
		$sql = "SELECT Author FROM ".$T_AUTHOR." WHERE id='".$a[$k]."'";
		$res = mysql_query($sql, $conn);
		$row = mysql_fetch_array($res, MYSQL_ASSOC);
		$author.=$row["Author"].", ";
	}
	$author = substr($author,0,-2);

	echo "<tr><td colspan=\"2\" style=\"text-align:left\;\"><b>";
	echo "<span title=\"eg Ikeno H, Nishioka T, ...\">Authors</span></b></td></tr>";

	echo "<tr><td>&nbsp;&nbsp;*in English</td>";
	echo "<td><input type=\"text\" style=\"width:90%\" name=\"author_e\" value=\"".$author."\"></td></tr>";

	echo "<tr><td>&nbsp;&nbsp; in other Language</td>";
	echo "<td><input type=\"text\" style=\"width:90%\" name=\"author_o\" value=\"".$item[a_jp]."\"></td>";
	echo "</tr>";

// Journal
	$sql = "SELECT * FROM ".$T_JOURNAL." WHERE id='".$item[j]."'";
	$res = mysql_query($sql, $conn);
	$row = mysql_fetch_array($res, MYSQL_ASSOC);

	echo "<tr><td colspan=\"2\" style=\"text-align:left\;\"><b>Journal/Book</b></td></tr>";
	echo "<tr><td> </td>";
	
	//journal select
	echo "<td><input type=\"radio\" name=\"jb\" value=\"j\"";
	if($row["Book"] == 0) echo "checked";
	echo ">";
	Get_Journal(0, $row["Journal"]);
	
	//book select
	echo "<br><input type=\"radio\" name=\"jb\" value=\"b\"";
	if($row["Book"] == 1) echo "checked";
	echo ">";
	Get_Journal(1, $row["Journal"]);
	echo "<br><br></td></tr>";


// Volume
	echo "<tr><td><b>Volume</b></td>";
	echo "<td><input type=\"text\" size=\"24\" name=\"volume\" value=\"$item[v]\"></td>";
	echo "</tr>";

// Pages
	echo "<tr><td><b>Pages</b></td>";
	echo "<td><input type=\"text\" size=\"24\" name=\"page\" value=\"$item[p]\"></td>";
	echo "</tr>";
// Year
		echo "<tr><td><b>Year</b></td>";
		if ( $item[y] != "0000" ) {
			echo "<td><input type=\"text\" size=\"24\" name=\"year\" value=\"$item[y]\">";
		} else {
			echo "<td><input type=\"text\" size=\"24\" name=\"year\">";
		}
		echo "</td>";
		echo "</tr>";

// Abstract
	echo "<tr><td><b>Abstract</b></td>";
	echo "<td><textarea name=\"abstract\" rows=\"10\" style=\"width:90%\" >$item[ab]</textarea></td>";
	echo "</tr>";

// PDF file
	echo "<tr><td><b>Upload</b></td>";
	echo "<td><input type=\"file\" name=\"userfile\"></td>";
	echo "</tr>";

	echo "<tr><td> </td>";
	echo "<td><input type=\"submit\" name=\"modify\" value=\"submit\"></td></tr>";

	echo "</table></div>";
	echo "<input type=\"hidden\" name=\"id\" value=\"$id\">";
	echo "<input type=\"hidden\" name=\"c_t1\" value=\"$item[c_t1]\">";
	echo "</form>";

// Remove form
	echo "<div class=\"pt\">"._MD_REMOVE_INFO."</div>";
	echo "<form enctype=\"multipart/form-data\" action=\"modify_wopmid.php\" method=\"POST\">";
	echo "<input type=\"submit\" name=\"remove\" value=\"remove\">";
	echo "<input type=\"hidden\" name=\"id\" value=\"$id\">";
	echo "<input type=\"hidden\" name=\"c_t1\" value=\"$item[c_t1]\">";
	echo "</form>";

	echo "<br><br><a href=\"index.php\">HOME</a>";
	include (XOOPS_ROOT_PATH."/footer.php");
?>

==> PPDF_1_3_1.zip: PubMedPDF/edit_wopmid.php <==
<?php
	include "header.php";
	include "include/db.php";
	include "include/Get_Journal.php";
	include "style.php";

	## edit

	$id = @$_GET["id"];

	$sql = "SELECT * FROM ".$T_ID." WHERE id=$id";
	$res = mysql_query($sql, $conn);

	if(!$row = mysql_fetch_array($res, MYSQL_ASSOC)) break;
	$item = array(
		"a"=>$row["Author"], "t"=>$row["Title"], "v"=>$row["Volume"], "p"=>$row["Page"], 
		"y"=>$row["Year"], "ab"=>$row["Abstract"], "j"=>$row["Journal"], "e"=>$row["editor"],
		"pub"=>$row["Publisher"], "t_jp"=>$row["Title_JP"], "a_jp"=>$row["Author_JP"],
		"c_t1"=>$row["Custom_t1"]
		);

// Edit form
	echo "<div class=\"pt\">"._MD_EDIT_INFO."</div>";
	echo "<br><form enctype=\"multipart/form-data\" action=\"modify_wopmid.php\" method=\"POST\">";
	echo "<div class=\"pc\">";
	echo "<table>";

// Title

	echo "<tr><td colspan=\"2\" style=\"text-align:left\;\"><b>Title</b></td></tr>";
	echo "<tr><td style=\"width:140px\" >&nbsp;&nbsp;*in English</td>";
	echo "<td><input type=\"text\" style=\"width:90%\" name=\"title_e\" value=\"".$item[t]."\"></td></tr>";

	echo "<tr><td>&nbsp;&nbsp; in other Language</td>";
	echo "<td><input type=\"text\" style=\"width:90%\" name=\"title_o\" value=\"".$item[t_jp]."\"></td></tr>";

// Authors
	$a = $item[a];
	$author="";
	$a = explode(",",substr($a,0,-1));
	for($k=0; $k<count($a); $k++){
		$a[$k] = str_replace("[","",$a[$k]);
		$a[$k] = str_replace("]","",$a[$k]);
		$sql = "SELECT Author FROM ".$T_AUTHOR." WHERE id='".$a[$k]."'";
		$res = mysql_query($sql, $conn);
		$row = mysql_fetch_array($res, MYSQL_ASSOC);
		$author.=$row["Author"].", ";
	}
	$author = substr($author,0,-2);

	echo "<tr><td colspan=\"2\" style=\"text-align:left\;\"><b>";
	echo "<span title=\"eg Ikeno H, Nishioka T, ...\">Authors</span></b></td></tr>";

	echo "<tr><td>&nbsp;&nbsp;*in English</td>";
	echo "<td><input type=\"text\" style=\"width:90%\" name=\"author_e\" value=\"".$author."\"></td></tr>";

	echo "<tr><td>&nbsp;&nbsp; in other Language</td>";
	echo "<td><input type=\"text\" style=\"width:90%\" name=\"author_o\" value=\"".$item[a_jp]."\"></td>";
	echo "</tr>";

// Journal
	$sql = "SELECT * FROM ".$T_JOURNAL." WHERE id='".$item[j]."'";
	$res = mysql_query($sql, $conn);
	$row = mysql_fetch_array($res, MYSQL_ASSOC);

	echo "<tr><td colspan=\"2\" style=\"text-align:left\;\"><b>Journal/Book</b></td></tr>";
	echo "<tr><td> </td>";
	
	//journal select
	echo "<td><input type=\"radio\" name=\"jb\" value=\"j\"";
	if($row["Book"] == 0) echo "checked";
	echo ">";
	Get_Journal(0, $row["Journal"]);
	
	//book select
	echo "<br><input type=\"radio\" name=\"jb\" value=\"b\"";
	if($row["Book"] == 1) echo "checked";
	echo ">";
	Get_Journal(1, $row["Journal"]);
	echo "<br><br></td></tr>";


// Volume
	echo "<tr><td><b>Volume</b></td>";
	echo "<td><input type=\"text\" size=\"24\" name=\"volume\" value=\"$item[v]\"></td>";
	echo "</tr>";

// Pages
	echo "<tr><td><b>Pages</b></td>";
	echo "<td><input type=\"text\" size=\"24\" name=\"page\" value=\"$item[p]\"></td>";
	echo "</tr>";
// Year
	echo "<tr><td><b>Year</b></td>";
	if ( $item[y] != "0000" ) {
		echo "<td><input type=\"text\" size=\"24\" name=\"year\" value=\"$item[y]\">";
	} else {
		echo "<td><input type=\"text\" size=\"24\" name=\"year\">";
	}
	echo "</td>";
	echo "</tr>";

// Abstract
	echo "<tr><td><b>Abstract</b></td>";
	echo "<td><textarea name=\"abstract\" rows=\"10\" style=\"width:90%\" >$item[ab]</textarea></td>";
	echo "</tr>";

// PDF file
/*
	echo "<tr><td><b>Upload</b></td>";
	echo "<td><input type=\"file\" name=\"userfile\"></td>";
	echo "</tr>";
*/
	echo "<tr><td> </td>";
	echo "<td><input type=\"submit\" name=\"modify\" value=\"submit\"></td></tr>";

	echo "</table></div>";
	echo "<input type=\"hidden\" name=\"id\" value=\"$id\">";
	echo "<input type=\"hidden\" name=\"c_t1\" value=\"$item[c_t1]\">";
	echo "</form>";

// PDF file upload form

	echo "<div class=\"pt\">"._MD_UPLOAD_INFO."</div>";
	echo "<form enctype=\"multipart/form-data\" action=\"modify_wopmid.php\" method=\"POST\">";
	echo "<div class=\"pc\">";
	echo "Upload File &nbsp;&nbsp;";
	echo "<input type=\"file\" name=\"userfile\">";
	echo "<input type=\"submit\" name=\"upload\" value=\"upload\">";
	echo "<input type=\"hidden\" name=\"id\" value=\"$id\">";
	echo "<input type=\"hidden\" name=\"c_t1\" value=\"$item[c_t1]\">";
	echo "</div>";
	echo "</form>";

// Remove form

	echo "<div class=\"pt\">"._MD_REMOVE_INFO."</div>";
	echo "<form enctype=\"multipart/form-data\" action=\"modify_wopmid.php\" method=\"POST\">";
	echo "<input type=\"submit\" name=\"remove\" value=\"remove\">";
	echo "<input type=\"hidden\" name=\"id\" value=\"$id\">";
	echo "<input type=\"hidden\" name=\"c_t1\" value=\"$item[c_t1]\">";
	echo "</form>";

	echo "<br><br><a href=\"index.php\">HOME</a>";
	include (XOOPS_ROOT_PATH."/footer.php");
?>
